# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""update NMT VLASS condor requirements

Revision ID: 2d8bd264bcfd
Revises: 548680252212
Create Date: 2021-09-30 09:32:04.301781

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "2d8bd264bcfd"
down_revision = "548680252212"
branch_labels = None
depends_on = None


condor = """executable = vlass_seci.sh
arguments = metadata.json PPR.xml

output = seci.out
error = seci.err
log = condor.log

VLASS_DIR = {{data_location}}
SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/vela, $(SBIN_PATH)/casa_envoy, ./working, ./rawdata, ./products, {{profile}}.properties, ./PPR.xml, ./metadata.json
transfer_output_files = rawdata, working, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=."

{{#remote}}
requirements = (VLASS == True)
+partition = "VLASS"
Rank = (TARGET.VLASS == True) + (TARGET.VLASSTEST =!= True)
{{/remote}}

queue

"""


old_condor = """executable = vlass_seci.sh
arguments = metadata.json PPR.xml

output = seci.out
error = seci.err
log = condor.log

VLASS_DIR = {{data_location}}
SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/vela, $(SBIN_PATH)/casa_envoy, ./working, ./rawdata, ./products, {{profile}}.properties, ./PPR.xml, ./metadata.json
transfer_output_files = rawdata, working, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=."

{{#remote}}requirements = (HasLustre =!= True){{/remote}}

queue

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{condor}' WHERE filename='vlass_seci.condor'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_condor}' WHERE filename='vlass_seci.condor'
        """
    )
