"""add ingest obs workflow

Revision ID: 491102d56809
Revises: 28b6a6bfb73c
Create Date: 2023-08-23 10:25:52.684465

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '491102d56809'
down_revision = '8ccdd4674889'
branch_labels = None
depends_on = None

wf_name = "ingest_obs"

ingest_obs_condor = """executable = ingest_obs.sh
arguments = metadata.json {{data_src}}

output = ingest.out
error = ingest.err
log = condor.log

should_transfer_files = NO
+WantIOProxy = True
request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"
requirements = HasLustre == True

queue

"""

ingest_obs_sh = """#!/bin/sh
set -o errexit

SBIN_PATH=/lustre/aoc/cluster/pipeline/$CAPO_PROFILE/workspaces/sbin

${SBIN_PATH}/ingest_envoy --observation $1 $2

"""

metadata_json = """{
  "telescope": "{{telescope}}",
  "data_location": "{{data_src}}",
  "projectMetadata": {
    "telescope": "{{telescope}}",
    "projectCode": "{{project_code}}"
  }
}

"""


def upgrade():
    op.execute(
        f"""
        INSERT INTO workflows (workflow_name, requires_lustre) VALUES (E'{wf_name}', true)
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('ingest_obs.condor', E'{ingest_obs_condor}', E'{wf_name}')
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('ingest_obs.sh', E'{ingest_obs_sh}', E'{wf_name}')
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('metadata.json', E'{metadata_json}', E'{wf_name}')
        """
    )


def downgrade():
    op.execute(
        f"""
        DELETE FROM workflow_templates WHERE workflow_name = E'{wf_name}'
        """
    )

    op.execute(
        f"""
        DELETE FROM workflows WHERE workflow_name = E'{wf_name}'
        """
    )
